@@ -34,5 +34,5 @@ def test_linear(slope: float = 2., intercept: float = 1.):
 def test_thermistor():
     """Test a spline conversion.
     """
-    file_path = PLASDUINO_SENSORS / 'NXFT15XH103FA2B.dat'
+    file_path = PLASDUINO_SENSORS / "NXFT15XH103FA2B.dat"
     _ = egu.ThermistorConversion.from_file(file_path, 10., 10, col_resistance=2)
